@@ -33,16 +33,16 @@ Parameters:
           Arguments will be split automatically.
   uri (string | null) (optional)
     URI for HTTP servers
-  env (object | null) (optional)
-    Environment variables
+  env (object | string | null) (optional)
+    Environment variables (dict or JSON string)
   cwd (string | null) (optional)
     Working directory (for commands)
   notes (string | null) (optional)
     Setup notes
   enable (boolean | null) (optional)
     Whether to enable the server immediately (default: True)
-  transport (object | null) (optional)
-    Transport-specific configuration (optional)
+  transport (object | string | null) (optional)
+    Transport-specific configuration (dict or JSON string)
     Common options for all command-based servers:
     - `keep_alive` (boolean): Keep the process alive between requests (default: true)
 
@@ -119,16 +119,29 @@ Parameters:
     Action to perform: list, info, or call.
   type (string) (required)
     Type of MCP capability to interact with: tool, resource, or prompt.
-  args (object | null) (optional)
+  args (object | string | null) (optional)
     Arguments for a 'call' action (call tool, read resource, or get prompt).
+    Can be provided as a dict or JSON string (automatically parsed).
   path (string | null) (optional)
     Name or URI of the specific tool/resource/prompt (with FastMCP prefixing).
     Not allowed for 'list' and 'info' actions.
+  limit (integer | null) (optional)
+    Maximum number of items to return (for 'list' action only). Default: 100, Max: 1000
+  offset (integer | null) (optional)
+    Number of items to skip (for 'list' action only). Default: 0
+  filter_server (string | null) (optional)
+    Filter results by server name prefix (for 'list' action only)
 
 Example usage (MBRO commands):
   - List all tools:
     -  `call proxy {"action": "list", "type": "tool"}`
 
+  - List tools with pagination:
+    -  `call proxy {"action": "list", "type": "tool", "limit": 50, "offset": 0}`
+
+  - List tools from a specific server:
+    -  `call proxy {"action": "list", "type": "tool", "filter_server": "serena_"}`
+
   - Get info about a specific tool:
     -  `call proxy {"action": "info", "type": "tool", "path": "calc:add"}`
 
